const matchGraphQL = { urls: ["https://graphql.landsbankinn.is/v2"] };

import { fetchAccounts } from './landsbankinn';
import { PartialStateUpdate, State } from './state';

type HttpHeaders = browser.webRequest.HttpHeaders;

function extractFromHeaders(headers: HttpHeaders): PartialStateUpdate {
    let apiKey = '';
    let gqlAuthToken = '';
    let rsaFingerprint = '';

    for (const header of headers) {
        switch (header.name.toLowerCase()) {
            case "authorization":
                gqlAuthToken = header.value || '';
                break;
            case "apikey":
                apiKey = header.value || '';
                break;
            case "rsa-fingerprint":
                rsaFingerprint = header.value || '';
                break;
        }
    }


    return { apiKey, gqlAuthToken, rsaFingerprint };
}

browser.webRequest.onBeforeSendHeaders.addListener(e => {
    // TODO if request errors, then clear state and try again.
    (async function() {
        const state = await State.current;
        if (!state.ready && e.requestHeaders) {
            console.info('Will update auth info from headers');

            // Lock ready to true so we don't have multiple attempts
            // at getting account info.
            await State.update({ ready: true });
            let newState = extractFromHeaders(e.requestHeaders);

            State.update(newState)
                .then(state => !state.accounts ? fetchAccounts() : state.accounts)
                .then(accounts => State.update({ accounts }))
                .then(() => console.log('done'));
        }
    })();
}, matchGraphQL, ["requestHeaders"]);

export { }
